# ExternalAPIDestinationRawData


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** | Destination ID | [readonly] 

## Example

```python
from openapi_client.models.external_api_destination_raw_data import ExternalAPIDestinationRawData

# TODO update the JSON string below
json = "{}"
# create an instance of ExternalAPIDestinationRawData from a JSON string
external_api_destination_raw_data_instance = ExternalAPIDestinationRawData.from_json(json)
# print the JSON string representation of the object
print(ExternalAPIDestinationRawData.to_json())

# convert the object into a dict
external_api_destination_raw_data_dict = external_api_destination_raw_data_instance.to_dict()
# create an instance of ExternalAPIDestinationRawData from a dict
external_api_destination_raw_data_from_dict = ExternalAPIDestinationRawData.from_dict(external_api_destination_raw_data_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


